package immibis.infinitubes;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.world.World;
import net.minecraftforge.common.ForgeDirection;
import net.minecraftforge.common.ISidedInventory;

public class InventoryHelper {
	public static IInventory getInventory(World world, int x, int y, int z, int side) {
		TileEntity te = world.getBlockTileEntity(x, y, z);
		if(te instanceof ISidedInventory) {
			ISidedInventory isi = (ISidedInventory)te;
			int start = isi.getStartInventorySide(ForgeDirection.VALID_DIRECTIONS[side]);
			int size = isi.getSizeInventorySide(ForgeDirection.VALID_DIRECTIONS[side]);
			if(size == 0)
				return null;
			return new RangeAdapter(isi, start, size);
		}
		if(te instanceof IInventory)
			return (IInventory)te;
		return null;
	}
	
	private static class RangeAdapter implements IInventory {
		private IInventory base;
		private int start, size;
		public RangeAdapter(IInventory base, int start, int size) {
			this.base = base;
			this.start = start;
			this.size = size;
		}
		@Override
		public int getSizeInventory() {
			return size;
		}
		@Override
		public ItemStack getStackInSlot(int var1) {
			return base.getStackInSlot(var1 + start);
		}
		@Override
		public ItemStack decrStackSize(int var1, int var2) {
			return base.decrStackSize(var1 + start, var2);
		}
		@Override
		public ItemStack getStackInSlotOnClosing(int var1) {
			return base.getStackInSlotOnClosing(var1 + start);
		}
		@Override
		public void setInventorySlotContents(int var1, ItemStack var2) {
			base.setInventorySlotContents(var1 + start, var2);
		}
		@Override
		public String getInvName() {
			return base.getInvName();
		}
		@Override
		public int getInventoryStackLimit() {
			return base.getInventoryStackLimit();
		}
		@Override
		public void onInventoryChanged() {
			base.onInventoryChanged();
		}
		@Override
		public boolean isUseableByPlayer(EntityPlayer var1) {
			return base.isUseableByPlayer(var1);
		}
		@Override
		public void openChest() {
			base.openChest();
		}
		@Override
		public void closeChest() {
			base.closeChest();
		}
	}

	public static IInventory getInventoryOnSide(World worldObj, int xCoord, int yCoord, int zCoord, int direction) {
		ForgeDirection fd = ForgeDirection.VALID_DIRECTIONS[direction];
		xCoord += fd.offsetX;
		yCoord += fd.offsetY;
		zCoord += fd.offsetZ;
		return getInventory(worldObj, xCoord, yCoord, zCoord, direction ^ 1);
	}
}
